package JoeDog::Config;

use strict;

my $LOCK_EX = 2;
my $LOCK_UN = 8;

=head1 NAME

JoeDog::Config - Perl extension for parsing configuration files.

=head1 SYNOPSIS

  use JoeDog::Config;
  my $config = new JoeDog::Config( filename );
  my @array  = $config->getColumn();
  my @array  = $config->getColumns();

=head1 METHODS

=item $config = new JoeDog::Config( filename );

Constructor for Config. Returns a reference to a JoeDog::Config object.

=cut

sub new( $ )
{
  my ( $this, $file )   =  @_;
  my $class             =  ref( $this ) || $this;
  my $self              =  {};
  $self->{"file"}       =  $file;
  bless( $self, $class );
  return $self;
}

=item my @array = $config->getColumn();

Reads the configuration file referenced by the constructor and 
returns an array populated with all the lines in the file. 

=cut 

sub getColumn
{
  my $this  = shift;
  my $lines = "";
  if( open ( FILE, "<" . $this->{"file"} )){
    flock( FILE, $LOCK_EX );
    while( <FILE> ){
      next if /^$/;           # Skip a blank line.
      next if /^\s*#/;        # Skip a comment line
      $lines = $lines . $_;   # Append to lines
    }
    flock( FILE, $LOCK_UN );
    close( FILE );
  }
  print $lines;
  return split( /\n/, $lines );
}

=item my @array = $config->getColumns( sep );

=cut

sub getColumns
{
  my $this  = shift;
  my ($sep) = @_;
  my $lines = "";
  my( @list, @cols );
  if( open ( FILE, "<" . $this->{"file"} )){
    flock( FILE, $LOCK_EX );
    while( <FILE> ){
      next if /^$/;
      next if /^\s*#/;
      $lines = $lines . $_;
    }
    flock( FILE, $LOCK_UN );
    close( FILE );
  }
  @list = split( /\n/, $lines );
  my $x = 0;
  foreach my $thing ( @list ){
    ( $cols[$x][0], $cols[$x][1] ) = split( /$sep/, $thing );
    $x ++;
  }
  return @cols;
}

sub getHash
{
  my $this  = shift;
  my ($sep,$bad_programmer) = @_;
  my (%hash, $hash);
  my $lines = "";
  my( @list, @cols );
  my($left,$right);

  if( open ( FILE, "<" . $this->{"file"} )){
    flock( FILE, $LOCK_EX );
    while( <FILE> ){
      next if /^$/;
      next if /^\s*#/;
      $lines .= $_;
    }
    flock( FILE, $LOCK_UN );
    close( FILE );
  }

  foreach my $thing ( split( /\n/, $lines ) ){
    ($left,$right) = split( /$sep/, $thing );
    # Trim begnining and trailing whitespace
    $left=~s/^\s+//;
    $right=~s/^\s+//;
    $left=~s/\s+$//;
    $right=~s/\s+$//;
    $hash{$left}=$right;
  }

  return %hash;
} 

=cut 

sub getFileName
{
  my $this = shift;
  return $this->{"file"};
}

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__

# Below is the stub of documentation for your module. You better edit it!

=head1 DESCRIPTION

Stub documentation for JoeDog::Config was created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.


=head1 AUTHOR

Jeffrey Fulmer, jdfulmer@armstrong.com

=head1 SEE ALSO

perl(1).

=cut
