package JoeDog::Wacky;

use IO::Socket;
use strict;

=head1 NAME

JoeDog::Config - Perl extension for parsing configuration files.

=head1 SYNOPSIS

  use JoeDog::Wacky;
  my $wacky = new JoeDog::Wacky( $hostname );
  $wacky->send( $pattern ); 
  $wacky->send( $message ); 
  $wacky->close( );

=head1 METHODS

=item $wacky = new JoeDog::Wacky( $hostname );

Constructor for Wacky.  Returns a reference to a JoeDog::Wacky object.

=cut

sub new( $ )
{
  my ( $this, $host )   =  @_;
  my $class             =  ref( $this ) || $this;
  my $self              =  
  {
    DEBUG   => 0,
    PORT    => 9193,
    EOL     => "\015\012",
    TIMEOUT => 60,
  };
  $self->{"HOST"}       =  $host;
  bless( $self, $class );

  $self->socket_connect();
  return $self;
}

sub 
socket_connect
{
  my $this   = shift;

  my $sock   = IO::Socket::INET->new(
    PeerAddr => $this->{HOST},
    PeerPort => $this->{PORT},
    Proto    => "tcp",
    Type     => SOCK_STREAM, 
    Timeout  => $this->{TIMEOUT},
  ) or die "can't connect to '$this->{HOST}:$this->{PORT}', $!";
 
  $this->{SOCKET} = $sock;
}

sub
get_socket
{
  my $this = shift;
  return $this->{'SOCKET'}; 
}


sub
socket_write
{
  my $this = shift;
  my $sock = $this->get_socket();
  print $sock @_;
}

=item I<send( $string )>

Sends a WACKY/1.0 protocol pattern to the referenced wackyd.

=cut 

sub send
{
  my $this  = shift;
  my($data) = @_;

  $this->socket_write( $data, $this->{EOL} );
}

=item I<close>

Close the wacky socket.

=cut

sub close
{
  my $this = shift;

  $this->socket_write( $this->{EOL} );
  close( $this->get_socket() ) or warn("close failed: $!");
}

1;
__END__

# Below is the stub of documentation for your module. You better edit it!

=head1 DESCRIPTION

Stub documentation for JoeDog::Config was created by h2xs. It looks like the
author of the extension was negligent enough to leave the stub
unedited.


=head1 AUTHOR

Jeffrey Fulmer, jdfulmer@armstrong.com

=head1 SEE ALSO

perl(1).

=cut
